@@ -579,6 +579,7 @@ class GPGStore:
                 if proc.poll() is not None:
                     break
             gpg_out = stderr_lookahead(proc)
+            assert_mdc(gpg_out)
             return capture_fpr(gpg_out)
 
     def gen_key(
@@ -843,3 +844,16 @@ def capture_fpr(b: bytes) -> List[str]:
         m.group(1).decode("utf-8", "replace")
         for m in re.finditer(rb"\[GNUPG:\] VALIDSIG ([0-9A-F]{40})", b)
     ]
+
+
+def assert_mdc(b: bytes) -> None:
+    """Assert that a valid MDC is present in the GPG output.
+
+    Modification Detection Code is used to detect if the encrypted message
+    has not been modified.
+
+    :param b: gpg stdout in binary form.
+    :raises GPGError: raised if GOODMDC is absend in the input.
+    """
+    if b"[GNUPG:] GOODMDC" not in b:
+        raise GPGError("Message integrity could not be verified.")
