@@ -6,6 +6,7 @@ from functools import partial
 
 import gpg_lite as gpg
 from gpg_lite import keyserver, store
+from gpg_lite.cmd import GPGError
 from gpg_lite.model import SignatureValidity
 
 ENV_WITH_GPG = os.environ.get("WITH_GPG", None) == "true"
@@ -438,6 +439,48 @@ gpg:          There is no indication that the signature belongs to the owner.
             ],
         )
 
+    def test_assert_mdc(self):
+        b = b"""
+[GNUPG:] ENC_TO AAAAAAAAAAAAA 1 0
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+[GNUPG:] DECRYPTION_KEY BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA u
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+gpg: encrypted with 4096-bit RSA key, ID AAAAAAAAAAAAA, created 2019-02-18
+      "Chuck Norris <chucknorris@roundhouse.gov>"
+[GNUPG:] BEGIN_DECRYPTION
+[GNUPG:] DECRYPTION_COMPLIANCE_MODE 23
+[GNUPG:] DECRYPTION_INFO 2 9
+[GNUPG:] PLAINTEXT 62 1628663575 test.txt
+[GNUPG:] PLAINTEXT_LENGTH 14
+[GNUPG:] NEWSIG
+gpg: Signature made Wed 11 Aug 2021 08:32:55 CEST
+gpg:                using RSA key AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+[GNUPG:] SIG_ID txTzNz6Yi2We04M0MWGw3pDp73w 2021-08-11 1628663575
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+[GNUPG:] GOODSIG 066E042415D8FD9C Chuck Norris <chucknorris@roundhouse.gov>
+gpg: Good signature from "Chuck Norris <chucknorris@roundhouse.gov>" [ultimate]
+[GNUPG:] VALIDSIG AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 2021-08-11 1628663575 0 4 0 1 10 00 AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+[GNUPG:] KEY_CONSIDERED AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0
+[GNUPG:] TRUST_ULTIMATE 0 pgp
+[GNUPG:] VERIFICATION_COMPLIANCE_MODE 23
+[GNUPG:] DECRYPTION_OKAY
+[GNUPG:] GOODMDC
+[GNUPG:] END_DECRYPTION
+"""
+        store.assert_mdc(b)
+
+        with self.assertRaises(GPGError) as cm:
+            store.assert_mdc(
+                b.replace(
+                    b"[GNUPG:] DECRYPTION_OKAY\n[GNUPG:] GOODMDC",
+                    b"gpg: WARNING: message was not integrity protected\n"
+                    b"gpg: decryption forced to fail!\n[GNUPG:] DECRYPTION_FAILED",
+                )
+            )
+        self.assertEqual(str(cm.exception), "Message integrity could not be verified.")
+
 
 class IntegrationTest(unittest.TestCase):
     def _setup_key(self):
@@ -548,6 +591,31 @@ class TestGPGIntegration(IntegrationTest):
         )
         self.assertEqual(decrypted.read(), message)
 
+        with self.subTest("Missing MDC"):
+            decrypted.seek(0)
+            decrypted.truncate()
+            encrypted_msg_without_mdc = (
+                b"\x84\x8c\x03\xf3\rL3@z?c\x01\x03\xfe=\x97\x01kJP"
+                b"\x90H\x06\x9a\xa2\x17!\xa8\xf9$n\xcf/\xad\xcb\xac\xc3;Y\xe9"
+                b"\xebw\x0c7^Z<\xces{\xfe\x9a*`\xcf\x01\x9d\xbcZ\r"
+                b"\xf4\x1ae0a3\x97 p\xc8\x9afa\xbd\x93\xea\xa3\xa4\xb9{"
+                b'\x18"\x10%\x9cZ\xea\xa8,,\xd7zt\xcf\xe3\xce.4\xe16'
+                b"\x01\xd0'\xab\x050<3\xc3xA\x13\xf3\x83\x83\xa2}\xc3X\xc5"
+                b"\xb1vE\xdeV\xd5of\x8c\xd1*\x04\xa03\xb6\xa5\xc0\xaf\x14~"
+                b"\xa3\x8c\xc9&\x18\xc5\xf4\xb8\x04\x99\x8a\t\x82f\xc2\xe1\xaf\xad\x85D"
+                b"\xf0\xfe2\xc5\x865\xb8m\xa3R\xd0\xfa\x13\xba*\x85\x0c\x9f\xbdS"
+                b"!\xbf"
+            )
+            with self.assertRaises(GPGError) as cm:
+                self.s.decrypt(
+                    source=io.BytesIO(encrypted_msg_without_mdc),
+                    output=capture_output,
+                    passphrase="test",
+                )
+            self.assertEqual(
+                str(cm.exception), "Message integrity could not be verified."
+            )
+
     def test_encrypt_decrypt(self):
         key = self._setup_key()
         message = b"a"
